@@ -2,7 +2,7 @@
 # coding:utf-8
 # Copyright (C) 2022 All rights reserved.
 # FILENAME:  load_config.py
-# VERSION: 	 0.1.2
+# VERSION: 	 0.1.3
 # CREATED: 	 2022-04-03 15:31
 # AUTHOR: 	 Sitt Guruvanich <aekazitt@gmail.com>
 # DESCRIPTION:
@@ -56,12 +56,13 @@ class LoadConfig(BaseModel):
   @validator('codec')
   def validate_codec(cls, value: str):
     if value.lower() not in {
-      'feather', 'hdf5', 'json', 'msgpack', 'orjson', 'parquet', 'pickle'
+      'csv', 'feather', 'json', 'msgpack', 'orjson', 'parquet', 'pickle'
     }:
       raise ValueError(
-        'The "codec" value must be one of "feather", "hdf5", "json", "msgpack", "orjson", ' \
+        'The "codec" value must be one of "csv", "feather", "json", "msgpack", "orjson", ' \
           '"parquet", or "pickle".' 
       )
+      ### TODO Validation when using DataFrame Codecs (csv, sql, feather, parquet) have pandas? ###
     return value
 
   @validator('redis_url', always=True)
